<div  align=center>
    <img src="Plastic-Metal.png" width = 30% height = 30%  />
</div>

# PlasticMetal.pyLabOn

![GitHub](https://img.shields.io/github/license/Plastic-Metal/pyLabOn?style=flat-square)

Light-weight tool to generate markdown-formatted lab reports. For python.
